#[repr(u32)]pub enum EventType {
Show 14 variants
Paired = 0,
Unpaired = 1,
Connected = 2,
Disconnected = 3,
ArmSynced = 4,
ArmUnsynced = 5,
Orientation = 6,
Pose = 7,
RSSI = 8,
Unlocked = 9,
Locked = 10,
EMG = 11,
BatteryLevel = 12,
WarmupCompleted = 13,
}Expand description
Types of events.
Variants
Paired = 0
Successfully paired with a Myo.
Unpaired = 1
Successfully unpaired from a Myo.
Connected = 2
A Myo has successfully connected.
Disconnected = 3
A Myo has been disconnected.
ArmSynced = 4
A Myo has recognized that the sync gesture has been successfully performed.
ArmUnsynced = 5
A Myo has been moved or removed from the arm.
Orientation = 6
Orientation data has been recevied.
Pose = 7
A change in pose has been detected. @see libmyo_pose_t.
RSSI = 8
An RSSI value has been received.
Unlocked = 9
A Myo has become unlocked.
Locked = 10
A Myo has become locked.
EMG = 11
EMG data has been received.
BatteryLevel = 12
A battery level value has been received.
WarmupCompleted = 13
The warmup period has completed.